<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 4.3.0
 */

defined('ABSPATH') || exit;

global $product;

if (!comments_open()) {
    return;
}

?>
<div id="reviews" class="woocommerce-Reviews">
    <div id="comments">
        <h2 class="woocommerce-Reviews-title">
            <?php
            $count = $product->get_review_count();
            if ($count && wc_review_ratings_enabled()) {
                /* translators: 1: reviews count 2: product name */
                $reviews_title = sprintf(esc_html(_n('%1$s review for %2$s', '%1$s reviews for %2$s', $count, 'organey')), esc_html($count), '<span>' . get_the_title() . '</span>');
                echo apply_filters('woocommerce_reviews_title', $reviews_title, $count, $product); // WPCS: XSS ok.
            } else {
                esc_html_e('Reviews', 'organey');
            }
            ?>
        </h2>
        <?php
        if (wc_review_ratings_enabled()) {

            $rating_count = $product->get_rating_count();
            $review_count = $product->get_review_count();
            $average      = $product->get_average_rating();
            $counts       = organey_get_review_counting();

            if ($rating_count > 0) : ?>
                <div class="review-top">
                    <div class="woocommerce-product-rating">
                        <?php echo wc_get_rating_html($average, $rating_count); // WPCS: XSS ok. ?>
                        <?php if (comments_open()) : ?>
                            <?php //phpcs:disable ?>
                            <a href="#reviews" class="woocommerce-review-link" rel="nofollow">(<?php printf(_n('%s customer review', '%s customer reviews', $review_count, 'organey'), '<span class="count">' . esc_html($review_count) . '</span>'); ?>
                                )</a>
                            <?php // phpcs:enable ?>
                        <?php endif ?>
                    </div>
                    <div class="reviews-summary">
                        <?php foreach ($counts as $key => $value): $pc = ($review_count == 0 ? 0 : (($value / $review_count) * 100));
                            $width = $key * 20;
                            ?>
                            <div class="review-summery-item">
                                <div class="star-rating"><span style="width:<?php echo esc_attr($width); ?>%"></span>
                                </div>
                                <div class="progress">
                                    <div class="progress-bar" style="width: <?php echo esc_attr($pc); ?>%;"></div>
                                </div>
                                <div class="progress-text"><?php echo round($pc, 2); ?>%</div>

                            </div>
                        <?php endforeach; ?>
                    </div>
                    <div class="review-button-wrap">
                        <?php if (comments_open()) : ?>
                            <?php //phpcs:disable ?>
                            <a href="#commentform" class="review-link" rel="nofollow"><?php echo esc_html__('Write A Review', 'organey'); ?></a>
                            <?php // phpcs:enable ?>
                        <?php endif ?>
                    </div>
                </div>

            <?php endif;
        }
        ?>

        <?php if (have_comments()) : ?>

            <ol class="commentlist">
                <?php wp_list_comments(apply_filters('woocommerce_product_review_list_args', array('callback' => 'woocommerce_comments'))); ?>
            </ol>

            <?php
            if (get_comment_pages_count() > 1 && get_option('page_comments')) :
                echo '<nav class="woocommerce-pagination">';
                paginate_comments_links(
                    apply_filters(
                        'woocommerce_comment_pagination_args',
                        array(
                            'prev_text' => '&larr;',
                            'next_text' => '&rarr;',
                            'type'      => 'list',
                        )
                    )
                );
                echo '</nav>';
            endif;
            ?>
        <?php else : ?>
            <p class="woocommerce-noreviews"><?php esc_html_e('There are no reviews yet.', 'organey'); ?></p>
        <?php endif; ?>
    </div>

    <?php if (get_option('woocommerce_review_rating_verification_required') === 'no' || wc_customer_bought_product('', get_current_user_id(), $product->get_id())) : ?>
        <div id="review_form_wrapper">
            <div id="review_form">
                <?php
                $commenter    = wp_get_current_commenter();
                $comment_form = array(
                    /* translators: %s is product title */
                    'title_reply'         => have_comments() ? esc_html__('Add a review', 'organey') : sprintf(esc_html__('Be the first to review &ldquo;%s&rdquo;', 'organey'), get_the_title()),
                    /* translators: %s is product title */
                    'title_reply_to'      => esc_html__('Leave a Reply to %s', 'organey'),
                    'title_reply_before'  => '<span id="reply-title" class="comment-reply-title">',
                    'title_reply_after'   => '</span>',
                    'comment_notes_after' => '',
                    'label_submit'        => esc_html__('Submit', 'organey'),
                    'logged_in_as'        => '',
                    'comment_field'       => '',
                );

                $name_email_required = (bool)get_option('require_name_email', 1);
                $fields              = array(
                    'author' => array(
                        'label'    => esc_html__('Name', 'organey'),
                        'type'     => 'text',
                        'value'    => $commenter['comment_author'],
                        'required' => $name_email_required,
                    ),
                    'email'  => array(
                        'label'    => esc_html__('Email', 'organey'),
                        'type'     => 'email',
                        'value'    => $commenter['comment_author_email'],
                        'required' => $name_email_required,
                    ),
                );

                $comment_form['fields'] = array();

                foreach ($fields as $key => $field) {
                    $field_html = '<p class="comment-form-' . esc_attr($key) . '">';
                    $field_html .= '<label for="' . esc_attr($key) . '">' . esc_html($field['label']);

                    if ($field['required']) {
                        $field_html .= '&nbsp;<span class="required">*</span>';
                    }

                    $field_html .= '</label><input id="' . esc_attr($key) . '" name="' . esc_attr($key) . '" type="' . esc_attr($field['type']) . '" value="' . esc_attr($field['value']) . '" size="30" ' . ($field['required'] ? 'required' : '') . ' /></p>';

                    $comment_form['fields'][$key] = $field_html;
                }

                $account_page_url = wc_get_page_permalink('myaccount');
                if ($account_page_url) {
                    /* translators: %s opening and closing link tags respectively */
                    $comment_form['must_log_in'] = '<p class="must-log-in">' . sprintf(esc_html__('You must be %1$slogged in%2$s to post a review.', 'organey'), '<a href="' . esc_url($account_page_url) . '">', '</a>') . '</p>';
                }

                if (wc_review_ratings_enabled()) {
                    $comment_form['comment_field'] = '<div class="comment-form-rating"><label for="rating">' . esc_html__('Your rating', 'organey') . (wc_review_ratings_required() ? '&nbsp;<span class="required">*</span>' : '') . '</label><select name="rating" id="rating" required>
						<option value="">' . esc_html__('Rate&hellip;', 'organey') . '</option>
						<option value="5">' . esc_html__('Perfect', 'organey') . '</option>
						<option value="4">' . esc_html__('Good', 'organey') . '</option>
						<option value="3">' . esc_html__('Average', 'organey') . '</option>
						<option value="2">' . esc_html__('Not that bad', 'organey') . '</option>
						<option value="1">' . esc_html__('Very poor', 'organey') . '</option>
					</select></div>';
                }

                $comment_form['comment_field'] .= '<p class="comment-form-comment"><label for="comment">' . esc_html__('Your review', 'organey') . '&nbsp;<span class="required">*</span></label><textarea id="comment" name="comment" cols="45" rows="8" required></textarea></p>';

                comment_form(apply_filters('woocommerce_product_review_comment_form_args', $comment_form));
                ?>
            </div>
        </div>
    <?php else : ?>
        <p class="woocommerce-verification-required"><?php esc_html_e('Only logged in customers who have purchased this product may leave a review.', 'organey'); ?></p>
    <?php endif; ?>

    <div class="clear"></div>
</div>
